.. BET documentation master file, created by
   sphinx-quickstart on Tue Apr 15 14:33:13 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BET's documentation!
===============================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   overview
   parallel
   examples_overview
   todo_list




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

